@@ -34,7 +34,9 @@ class PhotonOdometry:
             return None
 
         # field_to_target = self.field_layout.getTagPose(target.ID).translation().toTranslation2d()  # Coords of target relative to field
-        camera_to_target = target.relative_pose.translation().toTranslation2d() * self.camera.scale_constant  # Coords of target relative to camera
+        camera_to_target = target.relative_pose.translation().toTranslation2d() * self.camera.scale_constant
+        camera_to_target.y = -1 * camera_to_target.y  # Account for photon vision wrong direction
+        # Coords of target relative to camera
         camera_to_robot = self.camera.camera_to_robot_pose.translation().toTranslation2d()  # Coords of camera relative to robot
 
         field_to_robot = field_to_target - camera_to_target - camera_to_robot  # Reverse coords from field to target to camera to robot
